% Age model from Cunningham et al., Earth Surface Dynamics 2014 or 2015
%

% The script produces no graphics, so it can be run from the terminal.
% Run different samples/batches in multiple terminals for increased throughput 

% Specify the sample data. See the example for the format.
% Data stored in a matlab structure array
datalist=['struc1107146'];
% Or separate multiple samples with semi-colons, e.g. 
%datalist=['struc1110006'; 'struc1110005'; 'struc1110004'];

% SETTINGS  ============================================================
% Bootstrap settings:
M=1000; % number of bootstraps

% Phase_1 MCMC settings
MCPARAM.N_markov=3; %No markov chains for Phase 1
MCPARAM.m=1200; %Markov iterations for Phase 1

%Phase_2 (final) settings
min_i=1000; % min number iterations
max_i=7500; % max number of iterations

warning('off','all')
% ======================================================================

for j=1:length(datalist(:,1))
    
    % Load the measurement data for this sample
    load(datalist(j,:));
    eval(['datastruc=' datalist(j,:) ';']);
    disp(['starting sample: ' datalist(j,5:12)])
    
    % Specify and format other sample-specific info (e.g priors)
    % Follow the function for details
    struc = INP_FUNC_esurf(datastruc,datalist(j,5:12)); % 'struc' now contains the data
    delist=struc.de;    % CHANGE THESE TWO
    IPARAM=struc.IPARAM;
    
    % Create a text file to show the model progress
    logfile = ['log_' struc.SampleName '.txt'];
        fid=fopen(logfile,'w');
        fclose(fid);
    struc.logfile=logfile;
    
    
    %create bootstrap likelihoods for this dataset. theta, p, sd
    message='starting bootstrap likelihoods...';
    logthis(logfile,message);
    tic
        LIK = getLIK(delist,IPARAM,M,struc.mamflag);
        struc.LIK=LIK;
    tocmins=toc/60;
    message=['finished bootstrap likelihoods in ' sprintf('%1.0f',tocmins) ' mins'];
    logthis(logfile,message); disp(message)
        
    
    % The SG sensitivity =================================================
    tic
    message='starting findgamma...'; logthis(logfile,message); disp(message)
    
    % SG sensitivity distribution modelled with the gamma distribution
    % Get parameters a and b; they will be used as priors for the next stage 
    struc = findgamma_NGRAINS(struc,struc.sens,struc.sens_isize);
    
        tocmins=toc/60;
        message=['found gamma in ' sprintf('%1.0f',tocmins) ' mins'];
        logthis(logfile,message); disp(message)

    
    %PHASE 1: Short MCMC to define jumping distribution =================
    tic
    message='starting Phase1...'; logthis(logfile,message); disp(message)
    
        [Nlist, jlist] = Phase1_p5(IPARAM,MCPARAM,LIK,struc);
    
    tocmins=toc/60;
    message=['Phase1 finished in ' sprintf('%1.0f',tocmins) ' mins'];
    logthis(logfile,message); disp(message)

    struc.Phase1Nlist=Nlist;
    
    % if Phase_1 leaves carnage, then Phase_3 will fail. Use this
    % function to limit the mess:
    Nlist=massage_limits(Nlist(:,1:5)); 
    struc.jlist=jlist;
        
    %determine parameters of multivariate-normal
    Tlist=[];
    Tlist(:,1)=log(Nlist(:,1));
    Tlist(:,2)=log(Nlist(:,2));
    Tlist(:,3)=log(Nlist(:,3)./(1-Nlist(:,3))); %logit transform
    Tlist(:,4)=log(Nlist(:,4));
    Tlist(:,5)=log(Nlist(:,5));
    
    MVN.mu=mean(Tlist)';
    MVN.SIG=cov(Tlist);
    MVN.A=chol(MVN.SIG)';
    struc.MVN=MVN;

    %PHASE 3: MCMC till convergence =====================================
    tic
    message='starting Phase3...'; logthis(logfile,message); disp(message)
    [Nlist MARK] = Phase3_p5_jlist(IPARAM,MCPARAM,LIK,MVN,struc);
        tocmins=toc/60;
        message=['Phase3 finished in ' sprintf('%1.0f',tocmins) ' mins'];
        logthis(logfile,message); disp(message)
        
    struc.Nlist=Nlist;
    struc.MARK=MARK;
    
    newname=['strucG_' struc.SampleName];
    eval([newname ' = struc']); % new workspace variable
    fullname=[pwd filesep newname '.mat'];
    save(fullname,newname);
    message=['struc saved as: ' fullname]; logthis(logfile,message); disp(message)
end



